//
//  BBDXFEntityCircle.h
//  DXFReader
//
//  Created by Allan Daly (allan@brown-bird.net) on 2/2/09.
//	For information related to this framework see brown-bird.net.
//
//	********************************************************************************
//	Copyright (c) 2009 Allan Daly
//	All rights reserved.
//	
//	Redistribution and use in source and binary forms, with or without
//	modification, are permitted provided that the following conditions are met:
//	    * Redistributions of source code must retain the above copyright
//	      notice, this list of conditions and the following disclaimer.
//	    * Redistributions in binary form must reproduce the above copyright
//	      notice, this list of conditions and the following disclaimer in the
//	      documentation and/or other materials provided with the distribution.
//	    * Neither the name of Brown Bird nor the
//	      names of its contributors may be used to endorse or promote products
//	      derived from this software without specific prior written permission.
//	
//	THIS SOFTWARE IS PROVIDED BY ALLAN DALY ''AS IS'' AND ANY
//	EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
//	WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
//	DISCLAIMED. IN NO EVENT SHALL ALLAN DALY BE LIABLE FOR ANY
//	DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
//	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
//	LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
//	ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
//	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//	********************************************************************************
//

// header file HeaderDoc info
/*!
 @header		BBDXFEntityCircle.h
 
 @abstract		Subclass of BBDXFEntity. Defines class BBDXFEntityCircle, which holds the CIRCLE entity data elements.
 
 @discussion	BBDXFEntityCircle is an subclass of BBDXFEntity that provides a structure for the data elements
				defined in CIRCLE AutoCAD DXF entities. The data elements in this class plus those in the parent
				class make up all of the data found in the CIRCLE entity definition. (At this time, this implementation
				is not complete. See general discussion for more details.)
 */
#import <Cocoa/Cocoa.h>
#import "BBDXFEntity.h"

@class BB3DPoint;

/*!
 @abstract		Defines abstract class BBDXFEntityCircle to hold the CIRCLE DXF entity data.
 
 @discussion	BBDXFEntityCircle is a subclass of BBDXFEntity that provides a structure for the data elements
				in CIRCLE AutoCAD DXF entities.
 
				Instance variables defined in BBDXFEntityCircle are based on the AutoCAD 2009 DXF Reference
				available at <a href="http://images.autodesk.com/adsk/files/acad_dxf.pdf">http://images.autodesk.com/adsk/files/acad_dxf.pdf</a>
				as of 1/31/2009. The specific names used here were chosen to be consistent with this reference
				and use the AutoCAD terminology wherever possible.
 
				This implementation is not a complete set of the common DXF entity data items.
				See the AutoCAD 2009 DXF Reference listed above for the complete set.
 */
@interface BBDXFEntityCircle : BBDXFEntity {
	
	/*!
	 @abstract		Double value indicating line thickness.
	 @discussion	Contains the data from DXF entity group code 39. This is a double value indicating the line thickness.
	 
	 Group code 39:  thickness, double, default = 0
	 */
	double thickness;			// group code 39: double precision value
								//				  representing entity's thickness if non-zero
								//				  default = 0
	
	/*!
	 @abstract		3D point indicating the arc center point.
	 @discussion	Contains the data from DXF entity group codes 10, 20, 30. This is a 3D point indicating the arc center point. 
	 
	 Group codes 10, 20, 30:  center point, doubles, no default, but BB3DPoint objects are iniatilized to 0, 0, 0
	 */
	BB3DPoint * centerPoint;	// group codes 10, 20, 30 indicating x, y, z values for center point
	
	/*!
	 @abstract		Double value indicating circle radius.
	 @discussion	Contains the data from DXF entity group code 40. This is a double value indicating the circle radius.
	 
	 Group code 40:  radius, double, default = 0
	 */
	double radius;				// group code 40: double precision value
								//				  representing the arc's radius
								//				  default = 0
}

/*!
 @abstract	<i>thickness</i> instance variable accessible through standard methods.
 */
@property double thickness;

/*!
 @abstract	<i>centerPoint</i> instance variable accessible through standard methods.
 */
@property (retain) BB3DPoint * centerPoint;

/*!
 @abstract	<i>radius</i> instance variable accessible through standard methods.
 */
@property double radius;

@end