//
//  BBDXFEntityContainer.h
//  DXFReader
//
//  Created by Allan Daly on 4/4/09.
//	For information related to this framework see brown-bird.net.
//
//	********************************************************************************
//	Copyright (c) 2009 Allan Daly
//	All rights reserved.
//	
//	Redistribution and use in source and binary forms, with or without
//	modification, are permitted provided that the following conditions are met:
//	    * Redistributions of source code must retain the above copyright
//	      notice, this list of conditions and the following disclaimer.
//	    * Redistributions in binary form must reproduce the above copyright
//	      notice, this list of conditions and the following disclaimer in the
//	      documentation and/or other materials provided with the distribution.
//	    * Neither the name of Brown Bird nor the
//	      names of its contributors may be used to endorse or promote products
//	      derived from this software without specific prior written permission.
//	
//	THIS SOFTWARE IS PROVIDED BY ALLAN DALY ''AS IS'' AND ANY
//	EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
//	WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
//	DISCLAIMED. IN NO EVENT SHALL ALLAN DALY BE LIABLE FOR ANY
//	DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
//	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
//	LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
//	ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
//	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//	********************************************************************************
//

#import <Cocoa/Cocoa.h>

@class BBDXFEntity;

@interface BBDXFEntityContainer : NSObject {
	
	/*!
	 @abstract		Array of entities that belong to the block.
	 @discussion	A mutable array that holds all the entities that are part of a block definition.
	 */
	NSMutableArray * entityArray;
	
}

#pragma mark -
#pragma mark Entities Array Accessor and Utility Methods
/*!
 @abstract		￼Returns a reference to the entities array.
 @discussion	This is the method to call when you want to get the entities array.
 @result		NSMutableArray* [why is this a mutable array instead of a static array?] [AD-3/25/09: just returns a reference to the existing mutable array]
 @updated		2009-02-14
 */
- (NSMutableArray *) entityArray;				// returns a reference to the entity array

/*!
 @abstract   ￼	Adds an entity to the entities array.
 @param			newEntity	An BBDXFEntity object (or subclass) to be added to the entities array.
 @discussion	This is the method to call when adding an entity to the entities array. This is used in the
 processEntities method to create the entities array.
 @result		void
 @updated		2009-02-14
 */
- (void) addEntity:	(BBDXFEntity *) newEntity;  // add an entity to the entities array

/*!
 @abstract  ￼	Returns the entity from the entities array at the given index.
 @param			index	An int index value associated with an item in the entities array.
 @discussion	This is the method to call when you want to get an object out of the entities array.
 @result		BBDXFEntity reference
 @updated		2009-02-14
 */
- (BBDXFEntity *) entityAtIndex:			(int)			index;	// for accessing an entity in the entities array


@end
