//
//  BBDXFModel.h
//  DXFReader
//
//  Created by Allan Daly (allan@brown-bird.net) on 1/30/09.
//	For information related to this framework see brown-bird.net.
//
//	********************************************************************************
//	Copyright (c) 2009 Allan Daly
//	All rights reserved.
//	
//	Redistribution and use in source and binary forms, with or without
//	modification, are permitted provided that the following conditions are met:
//	    * Redistributions of source code must retain the above copyright
//	      notice, this list of conditions and the following disclaimer.
//	    * Redistributions in binary form must reproduce the above copyright
//	      notice, this list of conditions and the following disclaimer in the
//	      documentation and/or other materials provided with the distribution.
//	    * Neither the name of Brown Bird nor the
//	      names of its contributors may be used to endorse or promote products
//	      derived from this software without specific prior written permission.
//	
//	THIS SOFTWARE IS PROVIDED BY ALLAN DALY ''AS IS'' AND ANY
//	EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
//	WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
//	DISCLAIMED. IN NO EVENT SHALL ALLAN DALY BE LIABLE FOR ANY
//	DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
//	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
//	LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
//	ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
//	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//	********************************************************************************
//

// header file HeaderDoc info
/*!
 @header		BBDXFModel.h
 @abstract		Defines the BBDXFModel to represent the data in an ASCII DXF file.
 @discussion	This header defines class BBDXFModel.
 
 BBDXFModel represents the information contained in an ASCII DXF
 file. It receives its data from a text file formatted based on
 the AutoCAD DXF spec. It generates a custom BBDXFEntity object
 for each of the entities in the DXF file and stores the in an
 array of entities. This array can be used in any way needed by
 the program that uses the DXFReader framework.
 */
#import <Cocoa/Cocoa.h>
#import "BBDXFEntityContainer.h"

@class BBDXFEntity;

// BBDXFModel object HeaderDoc info
/*!
 @abstract		Defines the BBDXFModel to represent the data in an ASCII DXF file.
 
 @discussion	BBDXFModel represents the information contained in an ASCII DXF
				file. It receives its data from a text file that follows 
				the AutoCAD DXF spec. It generates a custom BBDXFEntity object
				for each of the entities in the DXF file and stores the in an
				array of entities. This array can be used in any way needed by
				the program that uses the DXFReader framework.
 */
@interface BBDXFModel : BBDXFEntityContainer {

	NSMutableDictionary * blocksDictionary;			// contains the block objects created from the BLOCKS section
	NSMutableDictionary * headerDictionary;			// contains the header variables with their values
}

#pragma mark -
#pragma mark Blocks Dictionary Accessor and Utility Methods
/*!
 @abstract		￼Returns the blocksDictionary.
 @discussion	This is the method to call when you want to get the blocks dictionary.
 @result		NSMutableDictionary
 @updated		2009-04-04
 */
- (NSMutableDictionary *) blocksDictionary;			// returns a reference to the blocks dictionary

#pragma mark -
#pragma mark Header Dictionary Accessor and Utility Methods
/*!
 @abstract		￼Returns the headerDictionary.
 @discussion	This is the method to call when you want to get the header dictionary.
 @result		NSMutableDictionary [why is this a mutable array instead of a static array?]
 @updated		2009-03-02
 */
- (NSMutableDictionary *) headerDictionary;			// returns a reference to the entity array

@end
